# Project-Utilities

The purpose of this package is to make life easier for all the developers out there who are working on a project. The package as I write this contains nothing but any contributions to the GitHub Repo [here] (https://github.com/RickarySanchez/project-utilities) would be greatly appreciated and added to the package. Some of the basic implementations I have considered adding are a file structure handling module which could make searching folders easy, and anything else in that realm. Also functions which create a release or make formatting code simple and easy. 